The relationship between the bounding box and the returned BNG grid squares
depends on the alignment of the bounding box with the BNG index system:
If the bounding box edges align with the BNG system (e.g. xmin, ymin, xmax,
ymax are multiples of the specified resolution), only the grid squares
entirely contained within the bounding box are returned. Grid squares that
intersect but are not fully contained within the bounding box are excluded.
If the bounding box edges are not aligned with the BNG system, grid squares
that are partially overlapped by the bounding box are also included. In this
case, the function ensures all relevant grid squares that the bounding box
touches are returned, including those at the edges.
Validates and normalises the bounding box coordinates to the BNG index system
extent. If bounding box coordinates fall outside of the BNG system extent,
the coordinates are snapped to the bounds of the BNG system.
Bounding boxes are expressed as four coordinates (min x, min y, max x, max
y). Coordinates must be in British National Grid projection (EPSG:27700).
These functions do not support coordinate transformations.
For matrix input, the first four columns are used as xmin, ymin, xmax, and
ymax, respectively. For data.frame input columns must be named "xmin",
"ymin", "xmax", and "ymax" or the first columns will be assumed.
To return the BNG grid squares within the bounding box of a geometry, see
geom_to_bng().