Learn R Programming

osbng (version 0.2.0)

get_bng_resolution: BNG reference resolution

Description

Find the spatial resolution (i.e. grid size) of a British National Grid square, or list valid resolutions.

Usage

get_bng_resolution(bng_ref)

get_bng_resolution_string(bng_ref)

list_bng_resolution(which = c("all", "whole", "quad"), lbl = FALSE)

Value

A vector of numeric values for get_bng_resolution() in metres or character strings expressing the resolution of the grid references.

vector of BNG resolutions as either numeric values or character labels.

Arguments

bng_ref

Vector of BNGReference objects to test.

which

character indicating what set of resolutions to return.

lbl

logical. Should resolutions labels be returned? Default is FALSE to return numeric resolutions.

Details

The integer values represent spatial resolutions in metres, while the string labels provide a human-readable descriptor for each resolution level. For example, the numeric resolution 1000 is mapped to the label '1km'.

Examples

Run this code
get_bng_resolution(as_bng_reference("TQ1234"))

get_bng_resolution_string(as_bng_reference("TQ1234NE"))

list_bng_resolution(which = "all", lbl = TRUE)

Run the code above in your browser using DataLab