a character vector of 2-letter identifiers for all valid 100km grid
squares. When arranged is TRUE this vector is coerced into a
2D matrix.
a numeric vector with four values for the xmin, ymin, xmax, and ymax
coordinates for the valid extant of the British National Grid.