bng_kring: Spatial neighbourhoods in the British National Grid index system
Description
Identify neighbours in a hollow ring or solid disc at grid distance 'k' from
a target BNG reference.
Usage
bng_kring(bng_ref, k, ...)
bng_kdisc(bng_ref, k, ...)
Value
list containing an unordered collection of objects of type
BNGReference within the neighbourhood around the given grid
reference.
Arguments
bng_ref
an object of type BNGReference
k
numeric value measuring the number of grid squares traversed between
the ring and input BNG reference
...
additional parameters. Not currently used
Details
K-rings are hollow rings of grid squares at a grid distance k
while k-discs are filled areas around a given grid square up to a grid
distance k. bng_kdisc includes the given BNG Reference (i.e. the
central grid square).
In the event that bng_ref is along the edge or corner of the valid
BNG area, then any return BNG references of the ring/disc outside the valid
BNG range will not be returned.